@@ -1,7 +1,7 @@
 import unittest
 
 import requests_mock
-from pyhalboy.pyhalboy import Navigator
+from pyhalboy import Navigator
 
 
 class NavigatorTestCase(unittest.TestCase):
