@@ -1,8 +1,8 @@
 import unittest
 import requests_mock
 
-from pyhalboy.pyhalboy import Resource
-from pyhalboy.pyhalboy import Navigator
+from pyhalboy import Resource
+from pyhalboy import Navigator
 
 
 def createUser(id, name):
